@@ -13,7 +13,6 @@ setClassUnion(name="label.class", members=c("call", "character", "function"))
 setClassUnion(name="prob.class", members=c("matrix", "numeric", "data.frame"))
 
 
-
 # ---- Data Class ----
 
 #' Class \code{'Data'}
@@ -1061,7 +1060,8 @@ setMethod("initialize", "MSE", function(.Object, Name, nyears, proyears,
 
   slts <- slotNames('MSE')
   for (sl in slts) {
-    slot(.Object, sl) <- get(sl)
+    var <- try(get(sl, inherits = FALSE), silent = TRUE)
+    if (!inherits(var, "try-error")) slot(.Object, sl) <- var
   }
   .Object
 })
@@ -1096,6 +1096,18 @@ setClass("PMobj", representation(Name = "character",  Caption='label.class',
 
 show <- function(object) methods::show(object)
 
+#' Print method for `multiHist` objects
+#' @param x For \code{print.multiHist}, a \code{multiHist} class object 
+#' @param ... Additional arguments (not used)
+#' @return Prints a summary of object `x` to the console
+#' @export
+print.multiHist <- function(x, ...) {
+  cli::cli_h2("A class `multiHist` Object")
+  cli::cli_text("A hierarchical list with {.val {length(x)}} Stocks and {.val {length(x[[1]])}} Fleets")
+  cli::cli_text("Use `multiHist[[st]][[fl]]` to access the `Hist` object for Stock `st` and Fleet `fl`")
+}
+
+
 
 #' Show the output of a PM
 #'
@@ -1147,9 +1159,10 @@ setMethod("show", signature = (object="PMobj"), function(object) {
     colnames(df) <- object@MPs
     names(lst) <- object@MPs
     if (nsim > (nprint+1)) {
-      ndots <- nsim-nprint-1
+      ndots <- min(nsim-nprint-1, 3)
       
-      dots <- df[1,]
+      dots <- df[1,, drop=FALSE]
+     
       dots[] <- '.'
       dots <- do.call("rbind", replicate(ndots, dots, simplify = FALSE))
       
@@ -1801,19 +1814,29 @@ setMethod("show", signature = (object="Rec"), function(object) {
 # ---- Internal show methods ----
 #' @importFrom utils capture.output str
 show_int <- function(object, slots_check) {
-  cat(paste0("S4 object of class ", dQuote(class(object)), ".\n"))
+  cli::cli_par()
+  
+  cli::cli_h2("A S4 object of class {.val {class(object)}}")
+  cli::cli_text("Access help documentation with: {.val {paste0('class?', class(object))}}")
+  
+  
+  # cat(paste0("S4 object of class ", dQuote(class(object)), ".\n"))
   if (!missing(slots_check)) {
+    cli::cli_par() 
     for(i in slots_check) {
       len <- length(slot(object, i))
-      if (len) cat(paste0(len, " items found in slot ", dQuote(i), ".\n"))
+      if (len) 
+        cli::cli_text("{len} item{?s} found in slot {.val {i}}")
     }
   }
-  cat("\n")
-  cat("Use str(), slotNames(),", dQuote("@"), "etc. to explore contents:\n\n")
   
-  txt <- capture.output(utils::str(object))
-  for(i in txt[1:5]) cat(i, "\n")
-  invisible()
+  cli::cli_text("\n\n") 
+  cli::cli_text("Use `str()`, `slotNames()` to explore object structure and `@` to access slots.")
+  # 
+  # txt <- capture.output(utils::str(object))
+  # 
+  # for(i in txt[1:5]) cli::cli_alert(i, "\n")
+  # invisible()
 }
 
 #' @name show-MSEtool
@@ -1828,6 +1851,8 @@ setMethod("show", "Data", function(object) show_int(object))
 #' @rdname show-MSEtool
 setMethod("show", "OM", function(object) show_int(object, slots_check = "cpars"))
 
+
+
 #' @rdname show-MSEtool
 setMethod("show", "Hist", function(object) show_int(object))
 
