@@ -83,7 +83,7 @@ setMethod("initialize", "MOM", function(.Object, Stocks=NULL, Fleets=NULL,
     .Object@seed <- 1
     return(.Object)
   }
-
+ 
 
   # Needed:
   # helper function to expand Fleets by stock
@@ -158,6 +158,11 @@ setMethod("initialize", "MOM", function(.Object, Stocks=NULL, Fleets=NULL,
 
 })
 
+#' @rdname show-MSEtool
+setMethod("show", "MOM", function(object) {
+  show_int(object)
+})
+
 
 # setGeneric("tinyErr", function(x, obs = TRUE, imp = TRUE, proc = TRUE, grad = TRUE, silent = FALSE)
 #   standardGeneric("tinyErr") )
