@@ -982,7 +982,7 @@ writeSection <- function(class=c("Intro", "Stock", "Fleet", "Obs", "Imp", "Refer
             #   val <- slot(OM, sl)
             # }
             if (is.numeric(val)) val <- round(val,2)
-            used <- length(val)>0 && !is.na(val) && !is.null(val) # is the slot used?
+            used <- length(val)>0 && !any(is.na(val)) && !is.null(val) # is the slot used?
             if (used) {
               val <- gsub('"', "", paste(val, collapse="\", \""))
               valtext <- paste0("Specified Value(s): ", "<span style='color:", color, "'>", " ", trimws(val), "</span>", "\n\n")
