@@ -116,61 +116,75 @@ NumericVector tdnorm(NumericVector x, double mi, double ma) {
 
 
 // [[Rcpp::export]]
-NumericMatrix  genSizeComp(NumericMatrix VulnN, NumericVector CAL_binsmid, NumericVector CAL_bins, NumericMatrix selCurve,
-                           double CAL_ESS, double CAL_nsamp,
-                           NumericVector Linfs, NumericVector Ks, NumericVector t0s,
-                           double LenCV, double truncSD) {
+NumericMatrix genSizeComp(NumericMatrix VulnN, 
+                          NumericVector CAL_binsmid, 
+                          NumericVector CAL_bins, 
+                          NumericMatrix selCurve,
+                          double CAL_ESS, 
+                          double CAL_nsamp,
+                          NumericVector Linfs, 
+                          NumericVector Ks, 
+                          NumericVector t0s,
+                          double LenCV, 
+                          double truncSD) {
+
   int nyears = VulnN.nrow();
-  int k = VulnN.ncol();
+  int k = VulnN.ncol(); // number of age classes
   int nbins = CAL_binsmid.size();
   NumericMatrix CAL(nyears, nbins);
-  //double width = CAL_binsmid(1) - CAL_binsmid(0);
-  //double origin = CAL_binsmid(0) - 0.5* width;
-  NumericVector temp(k);
-  NumericVector varAges = NumericVector::create(-0.6, -0.5, -0.4, -0.3, -0.2, -0.1, 0.0, 0.1, 0.2, 0.3, 0.4, 0.5); // monthly ages
+
+  NumericVector varAges = NumericVector::create(0.00000000, 0.08333333, 0.16666667, 
+                                                0.25000000, 0.33333333, 0.41666667,
+                                                0.50000000, 0.58333333, 0.66666667,
+                                                0.75000000, 0.83333333, 0.91666667); // monthly ages
+  
   for (int yr=0; yr < nyears; yr++) {
     NumericVector Nage = (VulnN.row(yr)); // numbers of catch-at-age this year
     double Ncatch = sum(Nage); // total catch this year
+   
     if (Ncatch>0) {
-      NumericVector Nage2 = (Nage/Ncatch) * CAL_ESS; // number-at-age effective sample
-      List Lens(k*12);
+      
+      List Lens(k*12); // list for each age class in each month
       int count = 0;
-      for (int age=0; age < k; age++) { // loop over 1:maxage
-        int Nage3 =  round(Nage2(age)); // number at this age
-        // NumericVector rands = RcppArmadillo::sample(NumericVector::create(0,1,2,3,4,5,6,7,8,9,10,11), Nage3, TRUE, NumericVector::create()) ; //  assume ages are uniformly distributed across months
-        // NumericVector subAgeVec = get_freq(rands, 1, 0, 12); // distribute n across months
+      for (int age=0; age < k; age++) { // loop over annual ages
+        
         // Calculate probability of sub-year age-classes
-        int n_age = 12;
-        NumericVector mean_length_at_sub_age(12);
+        int n_age = 12; 
         NumericMatrix ALK(n_age, nbins);
         NumericMatrix ALKs(n_age, nbins);
         NumericVector page(n_age);
         
         // calc select-at-subage
-        for (int subage=0; subage<=11; subage++) { // loop over 12 months
+        for (int subage=0; subage<n_age; subage++) { // loop over 12 months
           double sage = varAges(subage) + age;
-          mean_length_at_sub_age(subage) = Linfs(yr) * (1-exp(-Ks(yr)* (sage - t0s(yr))));
-          ALK(subage, _) = Rcpp::dnorm(CAL_binsmid, mean_length_at_sub_age(subage), mean_length_at_sub_age(subage)*LenCV, false);
+          double thislength = Linfs(yr) * (1-exp(-Ks(yr)* (sage - t0s(yr))));
+          if (thislength<0.001) {
+            thislength = 0.001;
+          }
+          ALK(subage, _) = Rcpp::dnorm(CAL_binsmid, thislength, thislength*LenCV, false);
           page(subage) = sum(ALK(subage,_));
         }
+        
         LogicalVector  b1 = page>0;
         if (is_false(all(b1))) {
           ALK(0,0) = 1;
         }
-       
+    
         NumericVector sela(n_age);
         for (int subage=0; subage<n_age; subage++) {
           if (page(subage)>0) {
             ALKs(subage,_) = ALK(subage,_)/page(subage);
-          }
+            }
           for (int len=0; len<nbins; len++) {
-            sela(subage) += ALKs(subage,len)*selCurve(len,yr);
+            sela(subage) += ALKs(subage,len)*selCurve(len,yr); // selectivity-at-age in each monthly time-step
           }
         }
         
-        // distribute sub-year ages across months proportional to selectivity-at-monthly-age
-        NumericVector probsubage = sela/sum(sela);
-        NumericVector subAgeVec = Nage3 * probsubage;
+
+        // distribute annual effective sample size proportional to relative monthly catch
+        double relnumber = Nage(age)/sum(Nage);
+        NumericVector probsubage = sela/sum(sela) * relnumber;
+        NumericVector subAgeVec = CAL_ESS * probsubage;
         
         // NumericVector subAgeVec = Nage3/NumericVector::create(1,2,3,4,5,6,7,8,9,10,11,12); // distribute n across months
         for (int subage=0; subage<=11; subage++) { // loop over 12 months
@@ -192,7 +206,9 @@ NumericMatrix  genSizeComp(NumericMatrix VulnN, NumericVector CAL_binsmid, Numer
           count += 1;
         }
       }
+      // out(0) = Lens;
       NumericVector LenVals = combine(Lens); // unlist
+      
       NumericVector templens = get_freq2(LenVals, CAL_bins, nbins); // calculate frequencies
       double rat = CAL_nsamp/sum(templens);
       templens =  templens * rat; // scale to CAL_nsamp
@@ -202,6 +218,7 @@ NumericMatrix  genSizeComp(NumericMatrix VulnN, NumericVector CAL_binsmid, Numer
       CAL(yr,_) = zeros;
     }
   }
+  
   return(CAL);
 }
 
